@@ -4,28 +4,24 @@
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation.
 
-"""Extractors for https://2chen.moe/"""
+"""Extractors for https://sturdychan.help/"""
 
 from .common import Extractor, Message
 from .. import text
 
+BASE_PATTERN = r"(?:https?://)?(?:sturdychan.help|2chen\.(?:moe|club))"
+
 
 class _2chenThreadExtractor(Extractor):
     """Extractor for 2chen threads"""
     category = "2chen"
     subcategory = "thread"
+    root = "https://sturdychan.help"
     directory_fmt = ("{category}", "{board}", "{thread} {title}")
     filename_fmt = "{time} {filename}.{extension}"
     archive_fmt = "{board}_{thread}_{hash}_{time}"
-    root = "https://2chen.moe"
-    pattern = r"(?:https?://)?2chen\.moe/([^/?#]+)/(\d+)"
-    test = (
-        ("https://2chen.moe/tv/496715", {
-            "count": ">= 179",
-        }),
-        # 404
-        ("https://2chen.moe/jp/303786"),
-    )
+    pattern = BASE_PATTERN + r"/([^/?#]+)/(\d+)"
+    example = "https://sturdychan.help/a/12345/"
 
     def __init__(self, match):
         Extractor.__init__(self, match)
@@ -36,13 +32,19 @@ class _2chenThreadExtractor(Extractor):
         page = self.request(url, encoding="utf-8", notfound="thread").text
         data = self.metadata(page)
         yield Message.Directory, data
+
         for post in self.posts(page):
-            if not post["url"]:
+
+            url = post["url"]
+            if not url:
                 continue
+            if url[0] == "/":
+                url = self.root + url
+            post["url"] = url = url.partition("?")[0]
+
             post.update(data)
-            post["url"] = self.root + post["url"]
             post["time"] = text.parse_int(post["date"].timestamp())
-            yield Message.Url, post["url"], text.nameext_from_url(
+            yield Message.Url, url, text.nameext_from_url(
                 post["filename"], post)
 
     def metadata(self, page):
@@ -78,15 +80,9 @@ class _2chenBoardExtractor(Extractor):
     """Extractor for 2chen boards"""
     category = "2chen"
     subcategory = "board"
-    root = "https://2chen.moe"
-    pattern = r"(?:https?://)?2chen\.moe/([^/?#]+)(?:/catalog|/?$)"
-    test = (
-        ("https://2chen.moe/co/", {
-            "pattern": _2chenThreadExtractor.pattern
-        }),
-        ("https://2chen.moe/co"),
-        ("https://2chen.moe/co/catalog")
-    )
+    root = "https://sturdychan.help"
+    pattern = BASE_PATTERN + r"/([^/?#]+)(?:/catalog|/?$)"
+    example = "https://sturdychan.help/a/"
 
     def __init__(self, match):
         Extractor.__init__(self, match)
