@@ -358,7 +358,7 @@ class TestPathfmt():
     def __enter__(self):
         return self
 
-    def __exit__(self, *args):
+    def __exit__(self, exc_type, exc_value, traceback):
         pass
 
     def open(self, mode):
